# -*- encoding: utf-8 -*-

require 'test_helper'

class DotConfig::ConfigurationTest < ActiveSupport::TestCase

  test 'class is defined' do
    assert DotConfig.const_defined?(:Configuration), 'Class undefined'
  end

  test 'default writing value' do
    assert_equal false, Configuration.new.writing
    assert_equal false, Configuration.new(writing: false).writing
    assert_equal true,  Configuration.new(writing: true).writing
  end

  test 'has new method' do
    assert_respond_to Configuration, :new, 'Method undefined'

    assert_nothing_raised(ArgumentError) do
      Configuration.new
      Configuration.new(writing: true)
      Configuration.new(config: { hello: :world })
      Configuration.new(config: { hello: :world }, writing: true)
    end
  end

  test 'new with config' do
    simple_hash = { language: 'Ruby', framework: 'Ruby on Rails' }
    config = Configuration.new(config: simple_hash)

    assert_equal simple_hash.keys, config.config.keys, 'Loosen keys'
    simple_hash.each { |key, value| assert_equal value, config.send(key.to_sym) }
  end

  test 'has config= method' do
    assert_respond_to Configuration.new, :config=, 'Method undefined'

    assert_nothing_raised(ArgumentError) do
      Configuration.new.config = { hello: :world }
      Configuration.new(writing: true).config = { hello: :world }
    end
  end

  test 'with nested config' do
    nested_hash = { language: 'Ruby',
                   framework: { rails: [:active_record, :active_support] } }
    config = Configuration.new(config: nested_hash)

    assert_instance_of Configuration, config.framework, 'Not a Configuration'
    assert_equal nested_hash[:framework][:rails], config.framework.rails
  end

  test 'getter method' do
    nested_hash = { language: 'Ruby',
                   framework: { rails: [:active_record, :active_support] } }
    config = Configuration.new(config: nested_hash)

    assert_instance_of nested_hash[:language].class, config.language
    assert_instance_of Configuration, config.framework
    assert_instance_of nested_hash[:framework][:rails].class, config.framework.rails
  end

  test 'setter method' do
    nested_hash = { language: 'Ruby',
                   framework: { rails: [:active_record, :active_support] } }

    config = Configuration.new(config: nested_hash)
    assert_raise(RuntimeError) { config.language = 'Python' }
    assert_equal nested_hash[:language], config.language

    config = Configuration.new(config: nested_hash, writing: true)
    config.language = 'Python'
    assert_equal 'Python', config.language
  end

  test 'to_hash method' do
    assert_respond_to Configuration.new, :to_hash, 'Method undefined'

    nested_hash = { language: 'Ruby',
                   framework: { rails: [:active_record, :active_support] } }
    config = Configuration.new(config: nested_hash)
    assert_equal config.to_hash, nested_hash
  end

  test 'private collision_name? method' do
    config = Configuration.new
    assert config.send(:collision_name?, %w{config})
    assert !config.send(:collision_name?, %w{world})
  end
end
